@@ -1,7 +1,7 @@
-"""
-Bounding regions and bounding boxes.
+"""Bounding regions and bounding boxes.
 
 File originally part of the Topographica project.
+
 """
 ### JABALERT: The aarect information should probably be rewritten in
 ### matrix notation, not list notation, so that it can be scaled,
@@ -13,11 +13,12 @@ from .util import datetime_types
 
 
 class BoundingRegion:
-    """
-    Abstract bounding region class, for any portion of a 2D plane.
+    """Abstract bounding region class, for any portion of a 2D plane.
 
     Only subclasses can be instantiated directly.
+
     """
+
     __abstract = True
 
     __slots__ = ['_aarect']
@@ -50,8 +51,8 @@ class BoundingRegion:
 
 
     def centroid(self):
-        """
-        Return the coordinates of the center of this BoundingBox
+        """Return the coordinates of the center of this BoundingBox
+
         """
         return self.aarect().centroid()
 
@@ -76,19 +77,20 @@ class BoundingRegion:
 
 
 class BoundingBox(BoundingRegion):
-    """
-    A rectangular bounding box defined either by two points forming
+    """A rectangular bounding box defined either by two points forming
     an axis-aligned rectangle (or simply a radius for a square).
+
     """
+
     __slots__ = []
 
 
     def __str__(self):
-        """
-        Return BoundingBox(points=((left,bottom),(right,top)))
+        """Return BoundingBox(points=((left,bottom),(right,top)))
 
         Reimplemented here so that 'print' for a BoundingBox
         will display the bounds.
+
         """
         l, b, r, t = self._aarect.lbrt()
         if (not isinstance(r, datetime_types) and r == -l and
@@ -113,13 +115,13 @@ class BoundingBox(BoundingRegion):
 
 
     def __init__(self, **args):
-        """
-        Create a BoundingBox.
+        """Create a BoundingBox.
 
         Either 'radius' or 'points' can be specified for the AARectangle.
 
         If neither radius nor points is passed in, create a default
         AARectangle defined by (-0.5,-0.5),(0.5,0.5).
+
         """
         # if present, 'radius', 'min_radius', and 'points' are deleted from
         # args before they're passed to the superclass (because they
@@ -147,30 +149,30 @@ class BoundingBox(BoundingRegion):
 
 
     def contains(self, x, y):
-        """
-        Returns true if the given point is contained within the
+        """Returns true if the given point is contained within the
         bounding box, where all boundaries of the box are
         considered to be inclusive.
+
         """
         left, bottom, right, top = self.aarect().lbrt()
         return (left <= x <= right) and (bottom <= y <= top)
 
 
     def contains_exclusive(self, x, y):
-        """
-        Return True if the given point is contained within the
+        """Return True if the given point is contained within the
         bounding box, where the bottom and right boundaries are
         considered exclusive.
+
         """
         left, bottom, right, top = self._aarect.lbrt()
         return (left <= x < right) and (bottom < y <= top)
 
 
     def containsbb_exclusive(self, x):
-        """
-        Returns true if the given BoundingBox x is contained within the
+        """Returns true if the given BoundingBox x is contained within the
         bounding box, where at least one of the boundaries of the box has
         to be exclusive.
+
         """
         left, bottom, right, top = self.aarect().lbrt()
         leftx, bottomx, rightx, topx = x.aarect().lbrt()
@@ -179,9 +181,9 @@ class BoundingBox(BoundingRegion):
 
 
     def containsbb_inclusive(self, x):
-        """
-        Returns true if the given BoundingBox x is contained within the
+        """Returns true if the given BoundingBox x is contained within the
         bounding box, including cases of exact match.
+
         """
         left, bottom, right, top = self.aarect().lbrt()
         leftx, bottomx, rightx, topx = x.aarect().lbrt()
@@ -190,12 +192,12 @@ class BoundingBox(BoundingRegion):
 
 
     def upperexclusive_contains(self, x, y):
-        """
-        Returns true if the given point is contained within the
+        """Returns true if the given point is contained within the
         bounding box, where the right and upper boundaries
         are exclusive, and the left and lower boundaries are
         inclusive.  Useful for tiling a plane into non-overlapping
         regions.
+
         """
         left, bottom, right, top = self.aarect().lbrt()
         return (left <= x < right) and (bottom <= y < top)
@@ -206,8 +208,8 @@ class BoundingBox(BoundingRegion):
 
 
     def lbrt(self):
-        """
-        return left,bottom,right,top values for the BoundingBox.
+        """Return left,bottom,right,top values for the BoundingBox.
+
         """
         return self._aarect.lbrt()
 
@@ -218,13 +220,17 @@ class BoundingBox(BoundingRegion):
         else:
             return False
 
+    def __hash__(self):
+        return hash(self.aarect)
+
 
 
 class BoundingEllipse(BoundingBox):
-    """
-    Similar to BoundingBox, but the region is the ellipse
+    """Similar to BoundingBox, but the region is the ellipse
     inscribed within the rectangle.
+
     """
+
     __slots__ = []
 
 
@@ -245,14 +251,17 @@ class BoundingEllipse(BoundingBox):
 # and use the slot itself instead.
 ###################################################
 class AARectangle:
-    """
-    Axis-aligned rectangle class.
+    """Axis-aligned rectangle class.
 
     Defines the smallest axis-aligned rectangle that encloses a set of
     points.
 
-    Usage:  aar = AARectangle( (x1,y1),(x2,y2), ... , (xN,yN) )
+    Examples
+    --------
+    >>> aar = AARectangle( (x1,y1),(x2,y2), ... , (xN,yN) )
+
     """
+
     __slots__ = ['_bottom', '_left', '_right', '_top']
 
 
@@ -278,33 +287,43 @@ class AARectangle:
 
 
     def top(self):
-        """Return the y-coordinate of the top of the rectangle."""
+        """Return the y-coordinate of the top of the rectangle.
+
+        """
         return self._top
 
 
     def bottom(self):
-        """Return the y-coordinate of the bottom of the rectangle."""
+        """Return the y-coordinate of the bottom of the rectangle.
+
+        """
         return self._bottom
 
 
     def left(self):
-        """Return the x-coordinate of the left side of the rectangle."""
+        """Return the x-coordinate of the left side of the rectangle.
+
+        """
         return self._left
 
 
     def right(self):
-        """Return the x-coordinate of the right side of the rectangle."""
+        """Return the x-coordinate of the right side of the rectangle.
+
+        """
         return self._right
 
 
     def lbrt(self):
-        """Return (left,bottom,right,top) as a tuple."""
+        """Return (left,bottom,right,top) as a tuple.
+
+        """
         return self._left, self._bottom, self._right, self._top
 
 
     def centroid(self):
-        """
-        Return the centroid of the rectangle.
+        """Return the centroid of the rectangle.
+
         """
         left, bottom, right, top = self.lbrt()
         return (right + left) / 2.0, (top + bottom) / 2.0
