@@ -6,14 +6,14 @@ from .. import util
 from ..dimension import dimension_name
 from ..element import Element
 from ..ndmapping import NdMapping, item_check, sorted_context
+from ..util import dtype_kind
 from .dictionary import DictInterface
 from .interface import DataError, Interface
 from .util import dask_array_module, finite_range, get_array_types, is_dask
 
 
 class GridInterface(DictInterface):
-    """
-    Interface for simple dictionary-based dataset format using a
+    """Interface for simple dictionary-based dataset format using a
     compressed representation that uses the cartesian product between
     key dimensions. As with DictInterface, the dictionary keys correspond
     to the column (i.e. dimension) names and the values are NumPy arrays
@@ -25,6 +25,7 @@ class GridInterface(DictInterface):
     instance, given an temperature recordings sampled regularly across
     the earth surface, a list of N unique latitudes and M unique
     longitudes can specify the position of NxM temperature samples.
+
     """
 
     types = (dict,)
@@ -52,10 +53,10 @@ class GridInterface(DictInterface):
             if (len(data) != len(dimensions) and len(data) == (ndims+1) and
                 len(data[-1].shape) == (ndims+1)):
                 value_array = data[-1]
-                data = {d: v for d, v in zip(dimensions, data[:-1])}
+                data = {d: v for d, v in zip(dimensions, data[:-1], strict=None)}
                 data[vdim_tuple] = value_array
             else:
-                data = {d: v for d, v in zip(dimensions, data)}
+                data = {d: v for d, v in zip(dimensions, data, strict=None)}
         elif (isinstance(data, list) and data == []):
             if len(kdims) == 1:
                 data = dict([(d, []) for d in dimensions])
@@ -67,7 +68,7 @@ class GridInterface(DictInterface):
                     data[vdim_tuple] = np.zeros((0, 0, len(vdims)))
         elif not any(isinstance(data, tuple(t for t in interface.types if t is not None))
                      for interface in cls.interfaces.values()):
-            data = {k: v for k, v in zip(dimensions, zip(*data))}
+            data = {k: v for k, v in zip(dimensions, zip(*data, strict=None), strict=None)}
         elif isinstance(data, np.ndarray):
             if data.shape == (0, 0) and len(vdims) == 1:
                 array = data
@@ -130,7 +131,7 @@ class GridInterface(DictInterface):
                             'match the expected dimensionality indicated '
                             f'by the key dimensions. Expected {len(expected)}-D array, '
                             f'found {len(shape)}-D array.')
-            elif any((e not in (s, s + 1)) for s, e in zip(shape, valid_shape)):
+            elif any((e not in (s, s + 1)) for s, e in zip(shape, valid_shape, strict=None)):
                 raise error(f'Key dimension values and value array {vdim} '
                             f'shapes do not match. Expected shape {valid_shape}, '
                             f'actual shape: {shape}', cls)
@@ -153,7 +154,7 @@ class GridInterface(DictInterface):
 
     @classmethod
     def concat_dim(cls, datasets, dim, vdims):
-        values, grids = zip(*datasets.items())
+        values, grids = zip(*datasets.items(), strict=None)
         new_data = {k: v for k, v in grids[0].items() if k not in vdims}
         new_data[dim.name] = np.array(values)
         for vdim in vdims:
@@ -245,6 +246,7 @@ class GridInterface(DictInterface):
         >>> GridInterface._infer_interval_breaks([[0, 1], [3, 4]], axis=1)
         array([[-0.5,  0.5,  1.5],
                [ 2.5,  3.5,  4.5]])
+
         """
         coord = np.asarray(coord)
         if coord.shape[axis] == 0:
@@ -262,10 +264,10 @@ class GridInterface(DictInterface):
 
     @classmethod
     def coords(cls, dataset, dim, ordered=False, expanded=False, edges=False):
-        """
-        Returns the coordinates along a dimension.  Ordered ensures
+        """Returns the coordinates along a dimension.  Ordered ensures
         coordinates are in ascending order and expanded creates
         ND-array matching the dimensionality of the dataset.
+
         """
         dim = dataset.get_dimension(dim, strict=True)
         irregular = cls.irregular(dataset, dim)
@@ -298,8 +300,7 @@ class GridInterface(DictInterface):
 
     @classmethod
     def canonicalize(cls, dataset, data, data_coords=None, virtual_coords=None):
-        """
-        Canonicalize takes an array of values as input and reorients
+        """Canonicalize takes an array of values as input and reorients
         and transposes it to match the canonical format expected by
         plotting functions. In certain cases the dimensions defined
         via the kdims of an Element may not match the dimensions of
@@ -311,6 +312,7 @@ class GridInterface(DictInterface):
         by some interfaces (e.g. xarray) to index irregular datasets
         with a virtual integer index. This ensures these coordinates
         are not simply dropped.
+
         """
         if virtual_coords is None:
             virtual_coords = []
@@ -376,7 +378,7 @@ class GridInterface(DictInterface):
         selected = {}
         adjusted_inds = []
         all_scalar = True
-        for kd, ind in zip(dataset.kdims[::-1], indices):
+        for kd, ind in zip(dataset.kdims[::-1], indices, strict=None):
             coords = cls.coords(dataset, kd.name, True)
             if np.isscalar(ind):
                 ind = [ind]
@@ -466,8 +468,8 @@ class GridInterface(DictInterface):
 
         # Iterate over the unique entries applying selection masks
         grouped_data = []
-        for unique_key in zip(*util.cartesian_product(keys)):
-            select = dict(zip(dim_names, unique_key))
+        for unique_key in zip(*util.cartesian_product(keys), strict=None):
+            select = dict(zip(dim_names, unique_key, strict=None))
             if drop_dim:
                 group_data = dataset.select(**select)
                 group_data = group_data if np.isscalar(group_data) else group_data.columns()
@@ -476,7 +478,7 @@ class GridInterface(DictInterface):
 
             if np.isscalar(group_data) or (isinstance(group_data, get_array_types()) and group_data.shape == ()):
                 group_data = {dataset.vdims[0].name: np.atleast_1d(group_data)}
-                for dim, v in zip(dim_names, unique_key):
+                for dim, v in zip(dim_names, unique_key, strict=None):
                     group_data[dim] = np.atleast_1d(v)
             elif not drop_dim:
                 if isinstance(group_data, get_array_types()):
@@ -497,7 +499,7 @@ class GridInterface(DictInterface):
 
     @classmethod
     def key_select_mask(cls, dataset, values, ind):
-        if values.dtype.kind == 'M':
+        if dtype_kind(values) == 'M':
             ind = util.parse_datetime_selection(ind)
         if isinstance(ind, tuple):
             ind = slice(*ind)
@@ -642,8 +644,8 @@ class GridInterface(DictInterface):
 
     @classmethod
     def sample(cls, dataset, samples=None):
-        """
-        Samples the gridded data into dataset of samples.
+        """Samples the gridded data into dataset of samples.
+
         """
         if samples is None:
             samples = []
@@ -658,15 +660,15 @@ class GridInterface(DictInterface):
                 sample = [sample[i] if i < len(sample) else None
                           for i in range(ndims)]
             sampled, int_inds = [], []
-            for d, ind in zip(dimensions, sample):
+            for d, ind in zip(dimensions, sample, strict=None):
                 cdata = dataset.data[d]
                 mask = cls.key_select_mask(dataset, cdata, ind)
                 inds = np.arange(len(cdata)) if mask is None else np.argwhere(mask)
                 int_inds.append(inds)
                 sampled.append(cdata[mask])
-            for d, arr in zip(dimensions, np.meshgrid(*sampled)):
+            for d, arr in zip(dimensions, np.meshgrid(*sampled), strict=None):
                 data[d].append(arr)
-            for vdim, array in zip(dataset.vdims, arrays):
+            for vdim, array in zip(dataset.vdims, arrays, strict=None):
                 da = dask_array_module()
                 flat_index = np.ravel_multi_index(tuple(int_inds)[::-1], array.shape)
                 if da and isinstance(array, da.Array):
@@ -795,7 +797,7 @@ class GridInterface(DictInterface):
         if len(array) == 0:
             return np.nan, np.nan
 
-        if array.dtype.kind == 'M':
+        if dtype_kind(array) == 'M':
             dmin, dmax = array.min(), array.max()
         else:
             try:
