@@ -7,11 +7,14 @@ import param
 from .. import util
 from ..element import Element
 from ..ndmapping import NdMapping
+from ..util import dtype_kind
 from .util import finite_range
 
 
 class DataError(ValueError):
-    "DataError is raised when the data cannot be interpreted"
+    """DataError is raised when the data cannot be interpreted
+
+    """
 
     def __init__(self, msg, interface=None):
         if interface is not None:
@@ -53,12 +56,12 @@ class Accessor:
 
 
 class iloc(Accessor):
-    """
-    iloc is small wrapper object that allows row, column based
+    """iloc is small wrapper object that allows row, column based
     indexing into a Dataset using the ``.iloc`` property.  It supports
     the usual numpy and pandas iloc indexing semantics including
     integer indices, slices, lists and arrays of values. For more
     information see the ``Dataset.iloc`` property docstring.
+
     """
 
     @classmethod
@@ -99,13 +102,14 @@ class iloc(Accessor):
 
 
 class ndloc(Accessor):
-    """
-    ndloc is a small wrapper object that allows ndarray-like indexing
+    """ndloc is a small wrapper object that allows ndarray-like indexing
     for gridded Datasets using the ``.ndloc`` property. It supports
     the standard NumPy ndarray indexing semantics including
     integer indices, slices, lists and arrays of values. For more
     information see the ``Dataset.ndloc`` property docstring.
+
     """
+
     @classmethod
     def _perform_getitem(cls, dataset, indices):
         ds = dataset
@@ -140,19 +144,19 @@ class Interface(param.Parameterized):
 
     @classmethod
     def loaded(cls):
-        """
-        Indicates whether the required dependencies are loaded.
+        """Indicates whether the required dependencies are loaded.
+
         """
         return True
 
     @classmethod
     def applies(cls, obj):
-        """
-        Indicates whether the interface is designed specifically to
+        """Indicates whether the interface is designed specifically to
         handle the supplied object's type. By default simply checks
         if the object is one of the types declared on the class,
         however if the type is expensive to import at load time the
         method may be overridden.
+
         """
         return type(obj) in cls.types
 
@@ -162,10 +166,10 @@ class Interface(param.Parameterized):
 
     @classmethod
     def cast(cls, datasets, datatype=None, cast_type=None):
-        """
-        Given a list of Dataset objects, cast them to the specified
+        """Given a list of Dataset objects, cast them to the specified
         datatype (by default the format matching the current interface)
         with the given cast_type (if specified).
+
         """
         datatype = datatype or cls.datatype
         cast = []
@@ -282,15 +286,15 @@ class Interface(param.Parameterized):
 
     @classmethod
     def persist(cls, dataset):
-        """
-        Should return a persisted version of the Dataset.
+        """Should return a persisted version of the Dataset.
+
         """
         return dataset
 
     @classmethod
     def compute(cls, dataset):
-        """
-        Should return a computed version of the Dataset.
+        """Should return a computed version of the Dataset.
+
         """
         return dataset
 
@@ -304,9 +308,9 @@ class Interface(param.Parameterized):
 
     @classmethod
     def isunique(cls, dataset, dim, per_geom=False):
-        """
-        Compatibility method introduced for v1.13.0 to smooth
+        """Compatibility method introduced for v1.13.0 to smooth
         over addition of per_geom kwarg for isscalar method.
+
         """
         try:
             return cls.isscalar(dataset, dim, per_geom)
@@ -324,8 +328,8 @@ class Interface(param.Parameterized):
 
     @classmethod
     def replace_value(cls, data, nodata):
-        """
-        Replace `nodata` value in data with NaN
+        """Replace `nodata` value in data with NaN
+
         """
         data = data.astype('float64')
         mask = data != nodata
@@ -335,11 +339,11 @@ class Interface(param.Parameterized):
 
     @classmethod
     def select_mask(cls, dataset, selection):
-        """
-        Given a Dataset object and a dictionary with dimension keys and
+        """Given a Dataset object and a dictionary with dimension keys and
         selection keys (i.e. tuple ranges, slices, sets, lists, or literals)
         return a boolean mask over the rows in the Dataset object that
         have been selected.
+
         """
         mask = np.ones(len(dataset), dtype=np.bool_)
         for dim, sel in selection.items():
@@ -395,9 +399,9 @@ class Interface(param.Parameterized):
 
     @classmethod
     def indexed(cls, dataset, selection):
-        """
-        Given a Dataset object and selection to be applied returns
+        """Given a Dataset object and selection to be applied returns
         boolean to indicate whether a scalar value has been indexed.
+
         """
         selected = list(selection.keys())
         all_scalar = all((not isinstance(sel, (tuple, slice, set, list))
@@ -409,32 +413,32 @@ class Interface(param.Parameterized):
     @classmethod
     def range(cls, dataset, dimension):
         column = dataset.dimension_values(dimension)
-        if column.dtype.kind == 'M':
+        if dtype_kind(column) == 'M':
             return column.min(), column.max()
         elif len(column) == 0:
             return np.nan, np.nan
         else:
             try:
-                assert column.dtype.kind not in 'SUO'
+                assert dtype_kind(column) not in 'SUO'
                 with warnings.catch_warnings():
                     warnings.filterwarnings('ignore', r'All-NaN (slice|axis) encountered')
                     return finite_range(column, np.nanmin(column), np.nanmax(column))
             except (AssertionError, TypeError):
                 column = [v for v in util.python2sort(column) if v is not None]
-                if not len(column):
+                if not column:
                     return np.nan, np.nan
                 return column[0], column[-1]
 
     @classmethod
     def concatenate(cls, datasets, datatype=None, new_type=None):
-        """
-        Utility function to concatenate an NdMapping of Dataset objects.
+        """Utility function to concatenate an NdMapping of Dataset objects.
+
         """
         from . import Dataset, default_datatype
         new_type = new_type or Dataset
         if isinstance(datasets, NdMapping):
             dimensions = datasets.kdims
-            keys, datasets = zip(*datasets.data.items())
+            keys, datasets = zip(*datasets.data.items(), strict=True)
         elif isinstance(datasets, list) and all(not isinstance(v, tuple) for v in datasets):
             # Allow concatenating list of datasets (by declaring no dimensions and keys)
             dimensions, keys = [], [()]*len(datasets)
@@ -459,7 +463,7 @@ class Interface(param.Parameterized):
 
         datasets = template.interface.cast(datasets, datatype)
         template = datasets[0]
-        data = list(zip(keys, datasets)) if keys else datasets
+        data = list(zip(keys, datasets, strict=None)) if keys else datasets
         concat_data = template.interface.concat(data, dimensions, vdims=template.vdims)
         return template.clone(concat_data, kdims=dimensions+template.kdims, new_type=new_type)
 
@@ -524,8 +528,8 @@ class Interface(param.Parameterized):
 
     @classmethod
     def as_dframe(cls, dataset):
-        """
-        Returns the data of a Dataset as a dataframe avoiding copying
+        """Returns the data of a Dataset as a dataframe avoiding copying
         if it already a dataframe type.
+
         """
         return dataset.dframe()
