@@ -1,7 +1,7 @@
-"""
-Advanced utilities for traversing nesting/hierarchical Dimensioned
+"""Advanced utilities for traversing nesting/hierarchical Dimensioned
 objects either to inspect the structure of their declared dimensions
 or mutate the matching elements.
+
 """
 
 from collections import defaultdict
@@ -13,15 +13,15 @@ from .util import merge_dimensions
 
 def create_ndkey(length, indexes, values):
     key = [None] * length
-    for i, v in zip(indexes, values):
+    for i, v in zip(indexes, values, strict=None):
         key[i] = v
     return tuple(key)
 
 def uniform(obj):
-    """
-    Finds all common dimension keys in the object including subsets of
+    """Finds all common dimension keys in the object including subsets of
     dimensions. If there are is no common subset of dimensions, None
     is returned.
+
     """
     from .spaces import HoloMap
     dim_groups = obj.traverse(lambda x: tuple(x.kdims),
@@ -33,13 +33,13 @@ def uniform(obj):
 
 
 def unique_dimkeys(obj, default_dim='Frame'):
-    """
-    Finds all common dimension keys in the object including subsets of
+    """Finds all common dimension keys in the object including subsets of
     dimensions. If there are is no common subset of dimensions, None
     is returned.
 
     Returns the list of dimensions followed by the list of unique
     keys.
+
     """
     from .ndmapping import NdMapping, item_check
     from .spaces import HoloMap
@@ -47,7 +47,7 @@ def unique_dimkeys(obj, default_dim='Frame'):
                                        list(x.data.keys())), (HoloMap,))
     if not key_dims:
         return [Dimension(default_dim)], [(0,)]
-    dim_groups, keys = zip(*sorted(key_dims, key=lambda x: -len(x[0])))
+    dim_groups, keys = zip(*sorted(key_dims, key=lambda x: -len(x[0])), strict=None)
     dgroups = [frozenset(d.name for d in dg) for dg in dim_groups]
     subset = all(g1 <= g2 or g1 >= g2 for g1 in dgroups for g2 in dgroups)
     # Find unique keys
@@ -64,7 +64,7 @@ def unique_dimkeys(obj, default_dim='Frame'):
         dim_keys = {}
         for dims, keys in key_dims:
             for key in keys:
-                for d, k in zip(dims, key):
+                for d, k in zip(dims, key, strict=None):
                     dim_keys[d.name] = k
         if dim_keys:
             keys = [tuple(dim_keys.get(dim.name) for dim in dimensions)]
@@ -74,13 +74,13 @@ def unique_dimkeys(obj, default_dim='Frame'):
 
     ndims = len(all_dims)
     unique_keys = []
-    for group, subkeys in zip(dim_groups, keys):
+    for group, subkeys in zip(dim_groups, keys, strict=None):
         dim_idxs = [all_dims.index(dim) for dim in group]
         for key in subkeys:
             padded_key = create_ndkey(ndims, dim_idxs, key)
             matches = [item for item in unique_keys
                        if padded_key == tuple(k if k is None else i
-                                              for i, k in zip(item, padded_key))]
+                                              for i, k in zip(item, padded_key, strict=None))]
             if not matches:
                 unique_keys.append(padded_key)
 
@@ -106,19 +106,19 @@ def bijective(keys):
 
 
 def hierarchical(keys):
-    """
-    Iterates over dimension values in keys, taking two sets
+    """Iterates over dimension values in keys, taking two sets
     of dimension values at a time to determine whether two
     consecutive dimensions have a one-to-many relationship.
     If they do a mapping between the first and second dimension
     values is returned. Returns a list of n-1 mappings, between
     consecutive dimensions.
+
     """
     ndims = len(keys[0])
     if ndims <= 1:
         return True
-    dim_vals = list(zip(*keys))
-    combinations = (zip(*dim_vals[i:i+2])
+    dim_vals = list(zip(*keys, strict=None))
+    combinations = (zip(*dim_vals[i:i+2], strict=None)
                     for i in range(ndims-1))
     hierarchies = []
     for combination in combinations:
