@@ -2,8 +2,11 @@ from collections import defaultdict
 
 import numpy as np
 import param
+from bokeh.models import FactorRange
 
 from ...core import util
+from ...core.dimension import Dimension
+from ...core.util import dtype_kind
 from ...element import Contours, Polygons
 from ...util.transform import dim
 from .callbacks import PolyDrawCallback, PolyEditCallback
@@ -76,8 +79,8 @@ class PathPlot(LegendPlot, ColorbarPlot):
 
 
     def _get_hover_data(self, data, element):
-        """
-        Initializes hover data based on Element dimension values.
+        """Initializes hover data based on Element dimension values.
+
         """
         if 'hover' not in self.handles or self.static_source:
             return
@@ -93,17 +96,20 @@ class PathPlot(LegendPlot, ColorbarPlot):
         cdim = None
         if isinstance(color, str) and not validate('color', color):
             cdim = element.get_dimension(color)
+        elif isinstance(color, Dimension):
+            # Handle hv.Dimension() objects directly
+            cdim = element.get_dimension(color.name) if color.name in element else color
         elif self.color_index is not None:
             cdim = element.get_dimension(self.color_index)
 
         scalar = element.interface.isunique(element, cdim, per_geom=True) if cdim else False
         style_mapping = {
             (s, v) for s, v in style.items() if (s not in self._nonvectorized_styles) and
-            ((isinstance(v, str) and v in element) or isinstance(v, dim)) and
-            not (not isinstance(v, dim) and v == color and s == 'color')}
+            (isinstance(v, str) and v in element) or isinstance(v, (dim, Dimension)) and
+            not (not isinstance(v, (dim, Dimension)) and v == color and s == 'color')}
         mapping = dict(self._mapping)
 
-        if (not cdim or scalar) and not style_mapping and 'hover' not in self.handles:
+        if not (cdim or style_mapping or 'hover' in self.handles):
             if self.static_source:
                 data = {}
             else:
@@ -118,7 +124,7 @@ class PathPlot(LegendPlot, ColorbarPlot):
         vals = defaultdict(list)
         if hover:
             vals.update({util.dimension_sanitizer(vd.name): [] for vd in element.vdims})
-        if cdim and self.color_index is not None:
+        if cdim:
             dim_name = util.dimension_sanitizer(cdim.name)
             cmapper = self._get_colormapper(cdim, element, ranges, style)
             mapping['line_color'] = {'field': dim_name, 'transform': cmapper}
@@ -126,15 +132,23 @@ class PathPlot(LegendPlot, ColorbarPlot):
 
         xpaths, ypaths = [], []
         for path in element.split():
-            if cdim and self.color_index is not None:
-                scalar = path.interface.isunique(path, cdim, per_geom=True)
-                cvals = path.dimension_values(cdim, not scalar)
-                vals[dim_name].append(cvals[:-1])
             cols = path.columns(path.kdims)
             xs, ys = (cols[kd.name] for kd in element.kdims)
             alen = len(xs)
-            xpaths += [xs[s1:s2+1] for (s1, s2) in zip(range(alen-1), range(1, alen+1))]
-            ypaths += [ys[s1:s2+1] for (s1, s2) in zip(range(alen-1), range(1, alen+1))]
+
+            if cdim:
+                scalar = path.interface.isunique(path, cdim, per_geom=True)
+                if scalar:
+                    # one value per geometry; repeat per segment
+                    cval = path.dimension_values(cdim, expanded=False)[0]
+                    vals[dim_name].append(np.full(alen-1, cval))
+                else:
+                    # per-vertex values; drop last to match segments
+                    cvals = path.dimension_values(cdim, expanded=True)
+                    vals[dim_name].append(cvals[:-1])
+
+            xpaths += [xs[s1:s2+1] for (s1, s2) in zip(range(alen-1), range(1, alen+1), strict=None)]
+            ypaths += [ys[s1:s2+1] for (s1, s2) in zip(range(alen-1), range(1, alen+1), strict=None)]
             if not hover:
                 continue
             for vd in element.vdims:
@@ -156,13 +170,13 @@ class PathPlot(LegendPlot, ColorbarPlot):
         data = defaultdict(list)
 
         zorders = self._updated_zorders(element)
-        for (key, el), zorder in zip(element.data.items(), zorders):
+        for (key, el), zorder in zip(element.data.items(), zorders, strict=None):
             el_opts = self.lookup_options(el, 'plot').options
             self.param.update(**{k: v for k, v in el_opts.items()
                                     if k not in OverlayPlot._propagate_options})
             style = self.lookup_options(el, 'style')
             style = style.max_cycles(len(self.ordering))[zorder]
-            self.overlay_dims = dict(zip(element.kdims, key))
+            self.overlay_dims = dict(zip(element.kdims, key, strict=None))
             eldata, elmapping, style = self.get_data(el, ranges, style)
             for k, eld in eldata.items():
                 data[k].extend(eld)
@@ -182,6 +196,50 @@ class PathPlot(LegendPlot, ColorbarPlot):
         return data, elmapping, style
 
 
+class DendrogramPlot(PathPlot):
+
+    def initialize_plot(self, ranges=None, plot=None, plots=None, source=None):
+        plot = super().initialize_plot(ranges, plot, plots, source)
+        if self.adjoined:
+            if self.layout_num and self.shared_axes:
+                msg = "Adjoined dendrogram in a Layout, does not currently support `.opts(shared_axes=True)`"
+                raise NotImplementedError(msg)
+            pos = ["main", "right", "top"][len(plots)]
+            main = self.adjoined[0]
+            if pos == "right":
+                if self.width == self.param.width.default:
+                    plot.width = 80
+                self._update_adjoined_figure(main, plot, "y")
+            elif pos == "top":
+                if self.height == self.param.height.default:
+                    plot.height = 80
+                self._update_adjoined_figure(main, plot, "x")
+        return plot
+
+    def _update_adjoined_figure(self, main, side, dim):
+        main_dim = getattr(main, f"{dim}_range").name
+        side_dim = f"{dim}s"
+        data = side.renderers[0].data_source.data
+        if isinstance(getattr(main, f"{dim}_range"), FactorRange):
+            # 0.5 is the factor used by Bokeh to convert a synthetic
+            # coordinate into a categorical factor.
+            # data_min.min() will for Scipy dendogram calculation be 5.
+            data_adj = np.asarray(data[side_dim])
+            data[side_dim] = list(0.5 / data_adj.min() * data_adj)
+        else:
+            main_src = main.renderers[0].data_source.data
+            data_adj, data_main = np.asarray(data[side_dim]), np.asarray(main_src.get(main_dim, main_src.get(f"{main_dim}s")))
+            if data_adj.size and data_main.size:
+                x1, x2, y1, y2 = data_adj.min(), data_adj.max(), data_main.min(), data_main.max()
+                data[side_dim] = list((y2 - y1) / (x2 - x1) * (data_adj - x1) + y1)
+            else:
+                data[side_dim] = data_adj
+
+        # Update range and scale to match main plot
+        setattr(side, f"{dim}_range", getattr(main, f"{dim}_range"))
+        setattr(side, f"{dim}_scale", getattr(main, f"{dim}_scale"))
+
+
 class ContourPlot(PathPlot):
 
     selected = param.List(default=None, doc="""
@@ -212,9 +270,9 @@ class ContourPlot(PathPlot):
         return dims, {}
 
     def _get_hover_data(self, data, element):
-        """
-        Initializes hover data based on Element dimension values.
+        """Initializes hover data based on Element dimension values.
         If empty initializes with no data.
+
         """
         if 'hover' not in self.handles or self.static_source:
             return
@@ -279,7 +337,7 @@ class ContourPlot(PathPlot):
         factors = None
         if cdim.label in ranges and 'factors' in ranges[cdim.label]:
             factors = ranges[cdim.label]['factors']
-        elif values.dtype.kind in 'SUO' and len(values):
+        elif dtype_kind(values) in 'SUO' and len(values):
             if isinstance(values[0], np.ndarray):
                 values = np.concatenate(values)
             factors = util.unique_array(values)
@@ -290,8 +348,8 @@ class ContourPlot(PathPlot):
         return data, mapping, style
 
     def _init_glyph(self, plot, mapping, properties):
-        """
-        Returns a Bokeh glyph object.
+        """Returns a Bokeh glyph object.
+
         """
         plot_method = properties.pop('plot_method', None)
         properties = mpl_to_bokeh(properties)
