@@ -13,23 +13,23 @@ from holoviews.core.data import Dataset
 from holoviews.core.util import PANDAS_VERSION
 from holoviews.util.transform import dim
 
-from ...utils import dask_switcher
 from .test_pandasinterface import BasePandasInterfaceTests
 
-try:
-    import dask_expr
-except ImportError:
-    dask_expr = None
 
-
-class _DaskDatasetTest(BasePandasInterfaceTests):
+class DaskDatasetTest(BasePandasInterfaceTests):
     """
     Test of the pandas DaskDataset interface.
     """
 
     datatype = 'dask'
+    data_type = dd.DataFrame
+    force_sort = True
 
-    __test__ = False
+    __test__ = True
+
+    def frame(self, *args, **kwargs):
+        df = pd.DataFrame(*args, **kwargs)
+        return dd.from_pandas(df, npartitions=2)
 
     # Disabled tests for NotImplemented methods
     def test_dataset_add_dimensions_values_hm(self):
@@ -109,23 +109,23 @@ class _DaskDatasetTest(BasePandasInterfaceTests):
         self.assertEqual(ds, Dataset(df, [('x', 'X'), ('y', 'Y')]))
 
     def test_dataset_range_categorical_dimension(self):
-        ddf = dd.from_pandas(pd.DataFrame({'a': ['1', '2', '3']}), 1)
+        ddf = self.frame({'a': ['1', '2', '3']})
         ds = Dataset(ddf)
         self.assertEqual(ds.range(0), ('1', '3'))
 
     def test_dataset_range_categorical_dimension_empty(self):
-        ddf = dd.from_pandas(pd.DataFrame({'a': ['1', '2', '3']}), 1)
+        ddf = self.frame({'a': ['1', '2', '3']})
         ds = Dataset(ddf).iloc[:0]
         ds_range = ds.range(0)
-        self.assertTrue(np.isnan(ds_range[0]))
-        self.assertTrue(np.isnan(ds_range[1]))
+        assert np.isnan(ds_range[0])
+        assert np.isnan(ds_range[1])
 
     def test_select_expression_lazy(self):
         df = pd.DataFrame({
             'a': [1, 2, 3, 4, 5],
             'b': [10, 10, 11, 11, 10],
         })
-        ddf = dd.from_pandas(df, npartitions=2)
+        ddf = self.frame(df)
         ds = Dataset(ddf)
         new_ds = ds.select(selection_expr=dim('b') == 10)
 
@@ -133,34 +133,7 @@ class _DaskDatasetTest(BasePandasInterfaceTests):
         self.assertIsInstance(new_ds.data, dd.DataFrame)
         self.assertEqual(new_ds.data.compute(), df[df.b == 10])
 
-
-class DaskClassicDatasetTest(_DaskDatasetTest):
-
-    data_type = dd.core.DataFrame
-
-    __test__ = True
-
-    @dask_switcher(query=False)
-    def setUp(self):
-        return super().setUp()
-
-
-class DaskExprDatasetTest(_DaskDatasetTest):
-
-    __test__ = bool(dask_expr)
-
-    @property
-    def data_type(self):
-        return dask_expr.DataFrame
-
-    @dask_switcher(query=True)
-    def setUp(self):
-        return super().setUp()
-
-    def test_dataset_groupby(self):
-        # Dask-expr unique sort the order when running unique on column
-        super().test_dataset_groupby(sort=True)
-
-    def test_dataset_groupby_alias(self):
-        # Dask-expr unique sort the order when running unique on column
-        super().test_dataset_groupby_alias(sort=True)
+    def test_dataset_get_dframe_by_dimension(self):
+        df = self.dataset_hm.dframe(['x'])
+        expected = self.frame({'x': self.xs}, dtype=df.dtypes.iloc[0]).compute()
+        self.assertEqual(df, expected)
