@@ -6,15 +6,16 @@ from functools import partial
 
 import param
 
-from holoviews.element.comparison import ComparisonTestCase
-from holoviews.element import Scatter
 from holoviews import streams
-from holoviews.core.spaces import Callable, Generator, DynamicMap
 from holoviews.core.operation import OperationCallable
+from holoviews.core.spaces import Callable, DynamicMap, Generator
+from holoviews.element import Scatter
+from holoviews.element.comparison import ComparisonTestCase
 from holoviews.operation import contours
 
 from ..utils import LoggingComparisonTestCase
 
+
 class CallableClass:
 
     @staticmethod
@@ -23,6 +24,9 @@ class CallableClass:
     @classmethod
     def someclsmethod(cls): pass
 
+    def someinstancemethod(self, x, y):
+        return x + y
+
     def __call__(self, *testargs):
         return sum(testargs)
 
@@ -65,6 +69,9 @@ class TestCallableName(ComparisonTestCase):
     def test_callable_class_call_method(self):
         self.assertEqual(Callable(CallableClass().__call__).name, 'CallableClass')
 
+    def test_callable_instance_method(self):
+        assert Callable(CallableClass().someinstancemethod).name == 'CallableClass.someinstancemethod'
+
     def test_classmethod_name(self):
         self.assertEqual(Callable(CallableClass().someclsmethod).name,
                          'CallableClass.someclsmethod')
@@ -105,7 +112,7 @@ class TestSimpleCallableInvocation(LoggingComparisonTestCase):
         self.log_handler.assertContains('WARNING', substr)
 
     def test_callable_lambda_extras_kwargs(self):
-        substr = "['x'] overriden by keywords"
+        substr = "['x'] overridden by keywords"
         self.assertEqual(Callable(lambda x,y: x+y)(3,5,x=10), 15)
         self.log_handler.assertEndsWith('WARNING', substr)
 
@@ -115,6 +122,12 @@ class TestSimpleCallableInvocation(LoggingComparisonTestCase):
     def test_callable_class(self):
         self.assertEqual(Callable(CallableClass())(1,2,3,4), 10)
 
+    def test_callable_instance_method(self):
+        assert Callable(CallableClass().someinstancemethod)(1, 2) == 3
+
+    def test_callable_partial_instance_method(self):
+        assert Callable(partial(CallableClass().someinstancemethod, x=1))(2) == 3
+
     def test_callable_paramfunc(self):
         self.assertEqual(Callable(ParamFunc)(3,b=5), 15)
 
@@ -142,6 +155,14 @@ class TestCallableArgspec(ComparisonTestCase):
         self.assertEqual(Callable(CallableClass()).argspec.keywords, None)
         self.assertEqual(Callable(CallableClass()).argspec.varargs, 'testargs')
 
+    def test_callable_instance_method(self):
+        assert Callable(CallableClass().someinstancemethod).argspec.args == ['x', 'y']
+        assert Callable(CallableClass().someinstancemethod).argspec.keywords is None
+
+    def test_callable_partial_instance_method(self):
+        assert Callable(partial(CallableClass().someinstancemethod, x=1)).argspec.args == ['y']
+        assert Callable(partial(CallableClass().someinstancemethod, x=1)).argspec.keywords is None
+
     def test_callable_paramfunc_argspec(self):
         self.assertEqual(Callable(ParamFunc).argspec.args, ['a'])
         self.assertEqual(Callable(ParamFunc).argspec.keywords, 'params')
@@ -169,6 +190,12 @@ class TestKwargCallableInvocation(ComparisonTestCase):
     def test_callable_partial(self):
         self.assertEqual(Callable(partial(lambda x,y: x+y,x=4))(y=5), 9)
 
+    def test_callable_instance_method(self):
+        assert Callable(CallableClass().someinstancemethod)(x=1, y=2) == 3
+
+    def test_callable_partial_instance_method(self):
+        assert Callable(partial(CallableClass().someinstancemethod, x=1))(y=2) == 3
+
     def test_callable_paramfunc(self):
         self.assertEqual(Callable(ParamFunc)(a=3,b=5), 15)
 
@@ -218,21 +245,21 @@ class TestDynamicMapInvocation(ComparisonTestCase):
 
     def test_dynamic_kdims_only(self):
         def fn(A,B):
-            return Scatter([(A,2)], label=A)
+            return Scatter([(B,2)], label=A)
 
         dmap = DynamicMap(fn, kdims=['A','B'])
         self.assertEqual(dmap['Test', 1], Scatter([(1, 2)], label='Test'))
 
     def test_dynamic_kdims_only_by_position(self):
         def fn(A,B):
-            return Scatter([(A,2)], label=A)
+            return Scatter([(B,2)], label=A)
 
         dmap = DynamicMap(fn, kdims=['A-dim','B-dim'])
         self.assertEqual(dmap['Test', 1], Scatter([(1, 2)], label='Test'))
 
     def test_dynamic_kdims_swapped_by_name(self):
         def fn(A,B):
-            return Scatter([(A,2)], label=A)
+            return Scatter([(B,2)], label=A)
 
         dmap = DynamicMap(fn, kdims=['B','A'])
         self.assertEqual(dmap[1,'Test'], Scatter([(1, 2)], label='Test'))
@@ -240,7 +267,7 @@ class TestDynamicMapInvocation(ComparisonTestCase):
 
     def test_dynamic_kdims_only_invalid(self):
         def fn(A,B):
-            return Scatter([(A,2)], label=A)
+            return Scatter([(B,2)], label=A)
 
         regexp="Callable 'fn' accepts more positional arguments than there are kdims and stream parameters"
         with self.assertRaisesRegex(KeyError, regexp):
@@ -250,7 +277,7 @@ class TestDynamicMapInvocation(ComparisonTestCase):
     def test_dynamic_kdims_args_only(self):
         def fn(*args):
             (A,B) = args
-            return Scatter([(A,2)], label=A)
+            return Scatter([(B,2)], label=A)
 
         dmap = DynamicMap(fn, kdims=['A','B'])
         self.assertEqual(dmap['Test', 1], Scatter([(1, 2)], label='Test'))
