@@ -1,13 +1,13 @@
 import operator
 from types import BuiltinFunctionType, BuiltinMethodType, FunctionType, MethodType
 
+import narwhals.stable.v2 as nw
 import numpy as np
-import pandas as pd
 import param
 
 from ..core.data import PandasInterface
 from ..core.dimension import Dimension
-from ..core.util import flatten, resolve_dependent_value, unique_iterator
+from ..core.util import dtype_kind, flatten, resolve_dependent_value, unique_iterator
 
 
 def _maybe_map(numpy_fn):
@@ -37,16 +37,28 @@ def norm(values, min=None, max=None):
 
         (values - min) / (max - min)
 
-    Args:
-        values: Array of values to be normalized
-        min (float, optional): Lower bound of normalization range
-        max (float, optional): Upper bound of normalization range
+    Parameters
+    ----------
+    values
+        Array of values to be normalized
+    min : float, optional
+        Lower bound of normalization range
+    max : float, optional
+        Upper bound of normalization range
 
-    Returns:
-        Array of normalized values
+    Returns
+    -------
+    Array of normalized values
     """
     min = np.min(values) if min is None else min
     max = np.max(values) if max is None else max
+    try:
+        # If it cannot be compared, this could be because of dask
+        comparison = bool(min == max)
+    except TypeError:
+        comparison = False
+    if comparison:
+        return values if max == 0 else (values / max)
     return (values - min) / (max-min)
 
 
@@ -54,13 +66,18 @@ def lognorm(values, min=None, max=None):
     """Unity-based normalization on log scale.
        Apply the same transformation as matplotlib.colors.LogNorm
 
-    Args:
-        values: Array of values to be normalized
-        min (float, optional): Lower bound of normalization range
-        max (float, optional): Upper bound of normalization range
+    Parameters
+    ----------
+    values
+        Array of values to be normalized
+    min : float, optional
+        Lower bound of normalization range
+    max : float, optional
+        Upper bound of normalization range
 
-    Returns:
-        Array of normalized values
+    Returns
+    -------
+    Array of normalized values
     """
     min = np.log(np.min(values)) if min is None else np.log(min)
     max = np.log(np.max(values)) if max is None else np.log(max)
@@ -69,6 +86,7 @@ def lognorm(values, min=None, max=None):
 
 class iloc:
     """Implements integer array indexing for dim expressions.
+
     """
 
     __name__ = 'iloc'
@@ -82,6 +100,7 @@ class iloc:
         return dim(self.expr, self)
 
     def __call__(self, values):
+        import pandas as pd
         if isinstance(values, (pd.Series, pd.DataFrame)):
             return values.iloc[resolve_dependent_value(self.index)]
         else:
@@ -90,6 +109,7 @@ class iloc:
 
 class loc:
     """Implements loc for dim expressions.
+
     """
 
     __name__ = 'loc'
@@ -114,23 +134,25 @@ def bin(values, bins, labels=None):
     with bin center values but an explicit list of bin labels may be
     defined.
 
-    Args:
-        values: Array of values to be binned
-        bins: List or array containing the bin boundaries
-        labels: List of labels to assign to each bin
-            If the bins are length N the labels should be length N-1
+    Parameters
+    ----------
+    values : Array of values to be binned
+    bins : List or array containing the bin boundaries
+    labels : List of labels to assign to each bin
+        If the bins are length N the labels should be length N-1
 
-    Returns:
-        Array of binned values
+    Returns
+    -------
+    Array of binned values
     """
     bins = np.asarray(bins)
     if labels is None:
         labels = (bins[:-1] + np.diff(bins)/2.)
     else:
         labels = np.asarray(labels)
-    dtype = 'float' if labels.dtype.kind == 'f' else 'O'
+    dtype = 'float' if dtype_kind(labels) == 'f' else 'O'
     binned = np.full_like(values, (np.nan if dtype == 'f' else None), dtype=dtype)
-    for lower, upper, label in zip(bins[:-1], bins[1:], labels):
+    for lower, upper, label in zip(bins[:-1], bins[1:], labels, strict=None):
         condition = (values > lower) & (values <= upper)
         binned[np.where(condition)[0]] = label
     return binned
@@ -143,13 +165,15 @@ def categorize(values, categories, default=None):
     Replaces discrete values in input array with a fixed set of
     categories defined either as a list or dictionary.
 
-    Args:
-        values: Array of values to be categorized
-        categories: List or dict of categories to map inputs to
-        default: Default value to assign if value not in categories
+    Parameters
+    ----------
+    values : Array of values to be categorized
+    categories : List or dict of categories to map inputs to
+    default : Default value to assign if value not in categories
 
-    Returns:
-        Array of categorized values
+    Returns
+    -------
+    Array of categorized values
     """
     uniq_cats = list(unique_iterator(values))
     cats = []
@@ -165,7 +189,7 @@ def categorize(values, categories, default=None):
         cats.append(cat)
     result = np.asarray(cats)
     # Convert unicode to object type like pandas does
-    if result.dtype.kind in ['U', 'S']:
+    if dtype_kind(result) in ['U', 'S']:
         result = result.astype('object')
     return result
 
@@ -189,11 +213,11 @@ function_types = (
 
 
 class dim:
-    """
-    dim transform objects are a way to express deferred transforms on
+    """dim transform objects are a way to express deferred transforms on
     Datasets. dim transforms support all mathematical and bitwise
     operators, NumPy ufuncs and methods, and provide a number of
     useful methods for normalizing, binning and categorizing data.
+
     """
 
     _binary_funcs = {
@@ -243,7 +267,7 @@ class dim:
         self.ops = []
         self._ns = np.ndarray
         self.coerce = kwargs.get('coerce', True)
-        if isinstance(obj, str):
+        if isinstance(obj, (str, tuple)):
             self.dimension = Dimension(obj)
         elif isinstance(obj, Dimension):
             self.dimension = obj
@@ -288,7 +312,7 @@ class dim:
             new_op = dict(op, fn=astype, args=(str,), kwargs={})
         else:
             new_op = dict(op, args=args, kwargs=kwargs)
-        return self.clone(self.dimension, self.ops[:-1]+[new_op])
+        return self.clone(self.dimension, [*self.ops[:-1], new_op])
 
     def __getattribute__(self, attr):
         self_dict = super().__getattribute__('__dict__')
@@ -324,9 +348,9 @@ class dim:
         return hash(repr(self))
 
     def clone(self, dimension=None, ops=None, dim_type=None):
-        """
-        Creates a clone of the dim expression optionally overriding
+        """Creates a clone of the dim expression optionally overriding
         the dim and ops.
+
         """
         dim_type = dim_type or type(self)
         if dimension is None:
@@ -339,9 +363,9 @@ class dim:
 
     @classmethod
     def register(cls, key, function):
-        """
-        Register a custom dim transform function which can from then
+        """Register a custom dim transform function which can from then
         on be referenced by the key.
+
         """
         cls._custom_funcs[key] = function
 
@@ -489,10 +513,12 @@ class dim:
         either computed from each bins center point or from the
         supplied labels.
 
-        Args:
-            bins: List or array containing the bin boundaries
-            labels: List of labels to assign to each bin
-                If the bins are length N the labels should be length N-1
+        Parameters
+        ----------
+        bins : List or array containing the bin boundaries
+
+        labels : List of labels to assign to each bin
+            If the bins are length N the labels should be length N-1
         """
         return type(self)(self, bin, bins, labels=labels)
 
@@ -502,9 +528,12 @@ class dim:
         Replaces discrete values in input array into a fixed set of
         categories defined either as a list or dictionary.
 
-        Args:
-            categories: List or dict of categories to map inputs to
-            default: Default value to assign if value not in categories
+        Parameters
+        ----------
+        categories
+            List or dict of categories to map inputs to
+        default
+            Default value to assign if value not in categories
         """
         return type(self)(self, categorize, categories=categories, default=default)
 
@@ -512,8 +541,10 @@ class dim:
         """Unity-based normalization log scale.
            Apply the same transformation as matplotlib.colors.LogNorm
 
-        Args:
-            limits: tuple of (min, max) defining the normalization range
+        Parameters
+        ----------
+        limits
+            tuple of (min, max) defining the normalization range
         """
         kwargs = {}
         if limits is not None:
@@ -525,8 +556,10 @@ class dim:
 
             (values - min) / (max - min)
 
-        Args:
-            limits: tuple of (min, max) defining the normalization range
+        Parameters
+        ----------
+        limits
+            tuple of (min, max) defining the normalization range
         """
         kwargs = {}
         if limits is not None:
@@ -535,10 +568,10 @@ class dim:
 
     @classmethod
     def pipe(cls, func, *args, **kwargs):
-        """
-        Wrapper to give multidimensional transforms a more intuitive syntax.
-        For a custom function 'func' with signature (*args, **kwargs), call as
+        """Wrapper to give multidimensional transforms a more intuitive syntax.
+        For a custom function `func` with signature (*args, **kwargs), call as
         dim.pipe(func, *args, **kwargs).
+
         """
         args = list(args) # make mutable
         for k, arg in enumerate(args):
@@ -548,16 +581,18 @@ class dim:
 
     @property
     def str(self):
-        "Casts values to strings or provides str accessor."
+        """Casts values to strings or provides str accessor.
+
+        """
         return type(self)(self, 'str', accessor=True)
 
     # Other methods
 
     def applies(self, dataset, strict=False):
-        """
-        Determines whether the dim transform can be applied to the
+        """Determines whether the dim transform can be applied to the
         Dataset, i.e. whether all referenced dimensions can be
         resolved.
+
         """
         from ..element import Graph
 
@@ -656,18 +691,20 @@ class dim:
         return data
 
     def _compute_data(self, data, drop_index, compute):
-        """
-        Implements conversion of data from namespace specific object,
+        """Implements conversion of data from namespace specific object,
         e.g. pandas Series to NumPy array.
+
         """
-        if hasattr(data, 'compute') and compute:
+        if compute and hasattr(data, 'compute'):
             data = data.compute()
+        if compute and hasattr(data, 'collect'):
+            data = data.collect()
         return data
 
     def _coerce(self, data):
-        """
-        Implements coercion of data from current data format to the
+        """Implements coercion of data from current data format to the
         namespace specific datatype.
+
         """
         return data
 
@@ -675,24 +712,35 @@ class dim:
               keep_index=False, compute=True, strict=False):
         """Evaluates the transform on the supplied dataset.
 
-        Args:
-            dataset: Dataset object to evaluate the expression on
-            flat: Whether to flatten the returned array
-            expanded: Whether to use the expanded expand values
-            ranges: Dictionary for ranges for normalization
-            all_values: Whether to evaluate on all values
-               Whether to evaluate on all available values, for some
-               element types, such as Graphs, this may include values
-               not included in the referenced column
-           keep_index: For data types that support indexes, whether the index
-               should be preserved in the result.
-           compute: For data types that support lazy evaluation, whether
-               the result should be computed before it is returned.
-           strict: Whether to strictly check for dimension matches
-               (if False, counts any dimensions with matching names as the same)
+        Parameters
+        ----------
+        dataset
+            Dataset object to evaluate the expression on
+        flat
+            Whether to flatten the returned array
+        expanded
+            Whether to use the expanded expand values
+        ranges
+            Dictionary for ranges for normalization
+        all_values
+            Whether to evaluate on all values
+            Whether to evaluate on all available values, for some
+            element types, such as Graphs, this may include values
+            not included in the referenced column
+        keep_index
+            For data types that support indexes, whether the index
+            should be preserved in the result.
+        compute
+            For data types that support lazy evaluation, whether
+            the result should be computed before it is returned.
+        strict
+            Whether to strictly check for dimension matches
+            (if False, counts any dimensions with matching names as the same)
 
-        Returns:
-            values: NumPy array computed by evaluating the expression
+        Returns
+        -------
+        values
+            NumPy array computed by evaluating the expression
         """
         from ..element import Graph
 
@@ -738,6 +786,9 @@ class dim:
         elif isinstance(dimension, param.Parameter):
             data = getattr(dimension.owner, dimension.name)
             eldim = None
+        elif isinstance(dataset.data, (nw.LazyFrame, nw.DataFrame)):
+            data = nw.col(dimension.name)
+            eldim = None
         else:
             lookup = dimension if strict else dimension.name
             eldim = dataset.get_dimension(lookup).name
@@ -856,10 +907,10 @@ class dim:
 
 
 class df_dim(dim):
-    """
-    A subclass of dim which provides access to the DataFrame namespace
+    """A subclass of dim which provides access to the DataFrame namespace
     along with tab-completion and type coercion allowing the expression
     to be applied on any columnar dataset.
+
     """
 
     namespace = 'dataframe'
@@ -867,6 +918,7 @@ class df_dim(dim):
     _accessor = 'pd'
 
     def __init__(self, obj, *args, **kwargs):
+        import pandas as pd
         super().__init__(obj, *args, **kwargs)
         self._ns = pd.Series
 
@@ -875,7 +927,7 @@ class df_dim(dim):
                 (coerce or isinstance(dataset.interface, PandasInterface)))
 
     def _compute_data(self, data, drop_index, compute):
-        if hasattr(data, 'compute') and compute:
+        if compute and hasattr(data, 'compute'):
             data = data.compute()
         if not drop_index:
             return data
@@ -897,10 +949,10 @@ class df_dim(dim):
 
 
 class xr_dim(dim):
-    """
-    A subclass of dim which provides access to the xarray DataArray
+    """A subclass of dim which provides access to the xarray DataArray
     namespace along with tab-completion and type coercion allowing
     the expression to be applied on any gridded dataset.
+
     """
 
     namespace = 'xarray'
@@ -934,32 +986,36 @@ class xr_dim(dim):
 
 
 def lon_lat_to_easting_northing(longitude, latitude):
-    """
-    Projects the given longitude, latitude values into Web Mercator
+    """Projects the given longitude, latitude values into Web Mercator
     (aka Pseudo-Mercator or EPSG:3857) coordinates.
 
     Longitude and latitude can be provided as scalars, Pandas columns,
     or Numpy arrays, and will be returned in the same form.  Lists
     or tuples will be converted to Numpy arrays.
 
-    Args:
-        longitude
-        latitude
+    Parameters
+    ----------
+    longitude
 
-    Returns:
-        (easting, northing)
+    latitude
 
-    Examples:
-       easting, northing = lon_lat_to_easting_northing(-74,40.71)
+    Returns
+    -------
+    (easting, northing)
 
-       easting, northing = lon_lat_to_easting_northing(
-           np.array([-74]),np.array([40.71])
-       )
+    Examples
+    --------
+    >>> easting, northing = lon_lat_to_easting_northing(-74,40.71)
 
-       df=pandas.DataFrame(dict(longitude=np.array([-74]),latitude=np.array([40.71])))
-       df.loc[:, 'longitude'], df.loc[:, 'latitude'] = lon_lat_to_easting_northing(
-           df.longitude,df.latitude
-       )
+    >>> easting, northing = lon_lat_to_easting_northing(
+        np.array([-74]),np.array([40.71])
+    )
+
+    >>> df=pandas.DataFrame(dict(longitude=np.array([-74]),latitude=np.array([40.71])))
+
+    >>> df.loc[:, 'longitude'], df.loc[:, 'latitude'] = lon_lat_to_easting_northing(
+        df.longitude,df.latitude
+    )
     """
     if isinstance(longitude, (list, tuple)):
         longitude = np.array(longitude)
@@ -976,19 +1032,21 @@ def lon_lat_to_easting_northing(longitude, latitude):
 
 
 def easting_northing_to_lon_lat(easting, northing):
-    """
-    Projects the given easting, northing values into
+    """Projects the given easting, northing values into
     longitude, latitude coordinates.
 
     easting and northing values are assumed to be in Web Mercator
     (aka Pseudo-Mercator or EPSG:3857) coordinates.
 
-    Args:
-        easting
-        northing
+    Parameters
+    ----------
+    easting
 
-    Returns:
-        (longitude, latitude)
+    northing
+
+    Returns
+    -------
+    (longitude, latitude)
     """
     if isinstance(easting, (list, tuple)):
         easting = np.array(easting)
